@@ -1,6 +1,7 @@
 import click
 from code_size_analyzer_client.client_wrapper import ClientWrapper
 import json
+from otel_extensions import init_telemetry_provider, TelemetryOptions
 
 
 @click.command()
@@ -19,6 +20,7 @@ import json
 @click.option("--output_file", default=None, help="path to output json file (default is to stdout)")
 @click.option("--verify_ssl", default=True, help="verify ssl certificate on server")
 def main(map_file, stack_name, target_part, compiler, project_file, service_url, output_file, verify_ssl):
+    init_telemetry_provider(TelemetryOptions(OTEL_SERVICE_NAME="Code Size Analyzer CLI"))
     client_wrapper = ClientWrapper(server_url=service_url, verify_ssl=verify_ssl)
     r = client_wrapper.analyze_map_file(
         map_file, stack_name, target_part, compiler, project_file
@@ -29,3 +31,6 @@ def main(map_file, stack_name, target_part, compiler, project_file, service_url,
             f.write(j)
     else:
         print(j)
+
+if __name__ == '__main__':
+    main()
\ No newline at end of file
